class Dspace::LearningObjectImporter

  def initialize(items)
    @items = items
  end

  def import
    items = []

    @items.each do |item|
      next if item_exists? item
      learning_object = LearningObjectBuilder.build_from_dspace(item)
      next if learning_object.blank?
      create_attachments(learning_object, item.bit_streams)
      items << learning_object
      yield(learning_object) if block_given?
    end

    LearningObject.import items, recursive: true
  end

  private

  def create_attachments(learning_object, bitstreams)
    bitstreams = JSON.parse bitstreams if bitstreams.class == String
    bitstreams.each do |bitstream|
      learning_object.attachments.new ::Dspace::AttachmentMapper.call(bitstream)
    end
  end

  def item_exists?(item)
    LearningObject.where(id_dspace: item.id).exists?
  end

end
